OC.L10N.register(
    "core",
    {
    "Please select a file." : "请选择一个文件。",
    "File is too big" : "文件太大",
    "The selected file is not an image." : "所选文件不是一张图片。",
    "The selected file cannot be read." : "无法读取所选文件。",
    "Invalid file provided" : "提供了无效文件",
    "No image or file provided" : "没有提供图片或文件",
    "Unknown filetype" : "未知的文件类型",
    "Invalid image" : "无效的图像",
    "An error occurred. Please contact your admin." : "发生了错误，请联系管理员。",
    "No temporary profile picture available, try again" : "没有临时个人页图片可用，请重试",
    "No crop data provided" : "没有提供剪裁数据",
    "No valid crop data provided" : "没有提供有效的裁剪数据",
    "Crop is not square" : "裁剪的不是正方形",
    "State token does not match" : "状态令牌无法匹配",
    "Could not complete login" : "无法完成登录",
    "Your login token is invalid or has expired" : "您的登录token无效或已过期",
    "Password reset is disabled" : "密码重置不可用",
    "Couldn't reset password because the token is invalid" : "令牌无效，无法重置密码",
    "Couldn't reset password because the token is expired" : "令牌已过期，无法重置密码",
    "%s password reset" : "重置 %s 的密码",
    "Password reset" : "重置密码",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "点击下面的按钮来重置您的密码。如果您并没有请求密码重置，请忽略这封邮件。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "点击下述链接重置您的密码。如果您没有请求重置密码，请忽略本邮件。",
    "Reset your password" : "重置您的密码",
    "Nextcloud Server" : "Nextcloud 服务器",
    "Some of your link shares have been removed" : "您的一些链接共享已被移除",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由于一个安全缺陷，我们必须移除您的部分链接共享。更多信息请查看此链接。",
    "Preparing update" : "正在准备更新",
    "[%d / %d]: %s" : "[%d / %d]：%s",
    "Repair step:" : "修复错误：",
    "Repair info:" : "修复信息：",
    "Repair warning:" : "修复警告：",
    "Repair error:" : "修复错误：",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "由于自动更新在 config.php 中已禁用，请使用命令行更新。",
    "[%d / %d]: Checking table %s" : "[%d / %d]：检查数据表 %s",
    "Turned on maintenance mode" : "启用维护模式",
    "Turned off maintenance mode" : "关闭维护模式",
    "Maintenance mode is kept active" : "维护模式已启用",
    "Updating database schema" : "正在更新数据库结构",
    "Updated database" : "数据库已更新",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "检查数据库结构是否可以更新（这可能需要很长的时间，这取决于数据库大小）",
    "Checked database schema update" : "已经检查数据库结构更新",
    "Checking updates of apps" : "检查更新应用",
    "Checking for update of app \"%s\" in appstore" : "检查%s应用是否有更新",
    "Update app \"%s\" from appstore" : "从应用商店更新%s应用",
    "Checked for update of app \"%s\" in appstore" : "已检查%s应用的是否有更新",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "检查 %s 的数据库结构是否可以更新（这可能需要很长的时间，取决于数据库大小）",
    "Checked database schema update for apps" : "已经检查应用的数据库结构更新",
    "Updated \"%1$s\" to %2$s" : "已更新 “%1$s” 到 %2$s",
    "Set log level to debug" : "设置日志级别为 调试",
    "Reset log level" : "重设日志级别",
    "Starting code integrity check" : "开始代码完整性检查",
    "Finished code integrity check" : "代码完整性检查完成",
    "%s (incompatible)" : "%s （不兼容）",
    "Following apps have been disabled: %s" : "下列应用已经被禁用：%s",
    "Already up to date" : "已经是最新",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "您的网页服务器没有正确设置允许文件同步，因为 WebDAV 接口看起来无法正常工作。",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "您的网页服务器未正确设置以解析“{url}”。更多信息请参见<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>。",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation page</a>. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的web服务器没有正确配置以解析 “{url}”。这很可能与web服务器配置没有更新，导致不能直接访问这个文件夹有关。请将您的配置与Apache “.htaccess”文件中的默认重写规则或者与这个<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档页面</a>中的Nginx配置进行比较。在Nginx配置中通常是以“location ~”开头的行需要修改。",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "您的网页服务器未正确设置以服务 .woff2 文件。这通常是一个 Nginx 配置的问题。对于 Nextcloud 15，需要更改一个设置才能服务 .woff2 文件。请将您的 Nginx 配置与我们<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>中推荐配置进行比较。",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP 的安装似乎不正确，无法访问系统环境变量。getenv(\"PATH\") 函数测试返回了一个空值。",
    "Please check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">installation documentation ↗</a> for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "请参照<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">安装说明文档 ↗</a>中的 PHP 配置说明查阅您服务器的PHP配置信息，特别是在使用 php-fpm 时。",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "只读配置已启用。这可以在浏览器界面保护配置。另外，每次更新时需手动赋予该文件写权限。",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "数据库没有运行在 \"READ COMMITTED\" 事务隔离级别。当多项操作同时执行时将产生问题。",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "未找到 PHP 的 \"fileinfo\" 模块。强烈推荐启用该模块，从而获得更好的 MIME 类型探测结果。",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a> for more information." : "已禁用事务性文件锁定，这可能在竞争条件下导致问题。在 config.php 中启用 \"filelocking.enabled\" 可以避免此问题。详情查阅 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档 ↗</a>。",
    "If your installation is not installed at the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (suggestion: \"{suggestedOverwriteCliURL}\")" : "如果没有将 Nextcloud 安装到域名根目录并使用系统计划任务，生成超链接就会出现问题。为避免此问题，请在 config.php 配置文件中将 \"overwrite.cli.url\" 设置为您 Nextcloud 安装的路径。（建议：\"{suggestedOverwriteCliURL}\"）",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "无法通过 CLI 执行计划任务，请查看以下技术错误：",
    "Last background job execution ran {relativeTime}. Something seems wrong." : "最近一次执行后台任务运行时间为 {relativeTime}，似乎哪里出了问题。",
    "Check the background job settings" : "请检查后台任务设置",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "此服务器没有可用的互联网连接：多个节点无法访问。这意味着某些功能比如挂载外部存储，更新通知以及安装第三方应用将无法工作。远程访问文件和发送通知邮件可能也不工作。启用这台服务器上的互联网连接以享用所有功能。",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "内存缓存未配置，为了提升使用体验，请尽量配置内存缓存。更多信息请参见<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>。",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "PHP 找不到合适的随机性来源，出于安全原因，我们强烈建议不要这样做。 更多信息可以在 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>中找到。",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "您当前正在运行 PHP 版本 {version}。我们建议您尽快在您的发行版支持新版本的时候进行升级，以获得<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{phpLink}\">来自 PHP 官方的性能和安全</a>的提升。",
    "You are currently running PHP 5.6. The current major version of Nextcloud is the last that is supported on PHP 5.6. It is recommended to upgrade the PHP version to 7.0+ to be able to upgrade to Nextcloud 14." : "您目前正在运行 PHP 5.6。 Nextcloud 的当前主要版本是最后一个支持 PHP 5.6 的版本。 建议将 PHP 版本升级到 7.0 以便能够升级到 Nextcloud 14。",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>." : "反向代理头部配置错误，或者您正在通过可信的代理访问 Nextcloud。如果您不是通过可信代理访问 Nextcloud，这是一个安全问题，它允许攻击者通过伪装 IP 地址访问 Nextcloud。更多信息请查看<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>。",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached 当前配置为分布式缓存，但是当前安装的 PHP 模块是 \"memcache\"。\\OC\\Memcache\\Memcached 仅支持 \"memcached\" 而不是 \"memcache\"。点击 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{wikiLink}\">memcached wiki </a>了解两者的差别。",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "一些文件没有通过完整性检查。了解如何解决该问题请查看我们的 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档</a>。(<a href=\"{codeIntegrityDownloadEndpoint}\">无效文件列表…</a> / <a href=\"{rescanEndpoint}\">重新扫描…</a>)",
    "The PHP OPcache module is not loaded. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to load it into your PHP installation." : "PHP 的 OPcache 模块未载入。<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">推荐开启获得更好的性能</a>。",
    "The PHP OPcache is not properly configured. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">For better performance it is recommended</a> to use the following settings in the <code>php.ini</code>:" : "PHP 的组件 OPcache 没有正确配置。 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">为了提供更好的性能</a>，我们建议在 <code>php.ini</code>中使用下列设置：",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP函数“set_time_limit”不可用。 这可能会导致脚本在执行过程中暂停，从而导致安装中断。 我们强烈建议启用此功能。",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 没有 FreeType 支持，导致配置文件图片和设置界面中断。",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "在数据表 \"{tableName}\" 中无法找到索引 \"{indexName}\"。",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "数据库丢失了一些索引。由于给大的数据表添加索引会耗费一些时间，因此程序没有自动对其进行修复。您可以在 Nextcloud 运行时通过命令行手动执行 \"occ db:add-missing-indices\" 命令修复丢失的索引。索引修复后会大大提高相应表的查询速度。",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "该实例缺失了一些推荐的 PHP 模块。为提高性能和兼容性，我们强烈建议安装它们。",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "数据库中的一些列由于进行长整型转换而缺失。由于在较大的数据表重改变列类型会耗费一些时间，因此程序没有自动对其更改。您可以通过命令行手动执行 \"occ db:convert-filecache-bigint\" 命令以应用挂起的更改。该操作需要当整个实例变为离线状态后执行。查阅<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">相关文档</a>以获得更多详情。",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "当前正在使用 SQLite 作为后端数据库。多用户使用时，推荐您改用其他的数据库。",
    "This is particularly recommended when using the desktop client for file synchronisation." : "特别推荐使用桌面客户端同步的用户选择。",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">documentation ↗</a>." : "迁移到其他数据库，使用命令：'occ db:convert-type' 或查阅 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">文档↗</a>。",
    "Use of the the built in php mailer is no longer supported. <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">Please update your email server settings ↗<a/>." : "PHP 内建的邮件发送器已不再受支持。<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">请更新您的 E-mail 服务器设置↗<a/>。",
    "The PHP memory limit is below the recommended value of 512MB." : "PHP 内存限制低于建议值 512MB。",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "有些应用程序目录是由与 Web 服务器不同的用户拥有的。如果应用程序是手动安装的，情况可能是这样的。检查以下应用程序目录的权限：",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">the documentation page about this</a>." : "所使用的数据库为MySQL但没有对4字节字符的支持。为正确处理文件名或评论中使用的4字节字符（比如emoji表情），建议开启MySQL的4字节字符支持。详细信息请阅读<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">相关文档页面</a>。",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "此实例使用基于S3的对象存储作为主存储。上传的文件会临时存放在服务器上，所以建议PHP的临时目录有50 GB的可用空间。路径和可用空间的详情请查看日志。要改善此状况请修改php.ini文件中的临时目录路径或增加该路径的可用空间。",
    "Error occurred while checking server setup" : "检查服务器设置时出错",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的数据目录和文件可以从互联网直接访问。.htaccess 文件不起作用。强烈建议您配置 Web 服务器，以便数据目录不再可访问，或者您可以将数据目录移动到 Web 服务器文档根目录。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP 请求头 \"{header}\" 没有配置为 \"{expected}\"。这是一个潜在的安全或隐私风险，我们建议您调整这项设置。",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP 请求头 \"{header}\" 没有配置为 \"{expected}\"。某些功能可能无法正常工作，因此建议相应地调整此设置。",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP 头 \"{header}\" 未包含 \"{expected}\"。这是一种潜在的安全或隐私风险，因此推荐调整此项设置。",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C Recommendation ↗</a>." : "HTTP 头 \"{header}\" 未设置成 \"{val1}\"，\"{val2}\"，\"{val3}\"，\"{val4}\" 或 \"{val5}\"。这会泄露更多的信息。请查阅 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{link}\">W3C 建议↗</a>。",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the <a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>." : "HTTP的请求头 \"Strict-Transport-Security\" 未设置为至少 \"{seconds}\" 秒。为了提高安全性，建议参照<a href=\"{docUrl}\" rel=\"noreferrer noopener\">security tips ↗</a>中的说明启用HSTS。",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "通过 HTTP 访问网站不安全。强烈建议您将服务器设置成要求使用HTTPS 协议，请查阅 <a href=\"{docUrl}\">安全贴士↗</a>。",
    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
    "restricted" : "受限",
    "invisible" : "不可见",
    "({scope})" : "({scope})",
    "Delete" : "删除",
    "Rename" : "重命名",
    "Collaborative tags" : "协作标签",
    "No tags found" : "标签未找到",
    "unknown text" : "未知文字",
    "Hello world!" : "你好，世界！",
    "sunny" : "晴",
    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是 {weather}",
    "Hello {name}" : "你好 {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>alert(1)</script></strong>",
    "new" : "新建",
    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些环境下离开当前页面可能会中断。",
    "Update to {version}" : "升级到 {version}",
    "An error occurred." : "发生错误。",
    "Please reload the page." : "请重新加载页面。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新不成功。有关此问题的更多信息请<a href=\"{url}\">查看我们的论坛帖子</a>。",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 社区</a>。",
    "Continue to Nextcloud" : "继续访问 Nextcloud",
    "_The update was successful. Redirecting you to Nextcloud in %n second._::_The update was successful. Redirecting you to Nextcloud in %n seconds._" : ["升级成功，在%n秒内重定向到 Nextcloud。"],
    "Searching other places" : "搜索其他位置",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它的文件夹里没有关于 {tag}{filter}{endtag} 的搜索结果",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["在其他文件夹中找到 {count} 条搜索结果"],
    "Server side authentication failed!" : "服务端认证失败！",
    "Please contact your administrator." : "请联系您的管理员。",
    "An internal error occurred." : "发生了内部错误。",
    "Please try again or contact your administrator." : "请重试或联系您的管理员。",
    "Username or email" : "用户名或邮箱",
    "Username or\temail" : "用户名或\t邮箱",
    "Password" : "密码",
    "Log in" : "登录",
    "Logging in …" : "正在登录 …",
    "Wrong username or password." : "错误的用户名或密码。",
    "User disabled" : "用户不可用",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到您的 IP 进行了多次无效登录尝试。因此，请 30 秒之后再尝试。",
    "Reset password" : "重置密码",
    "A password reset message has been sent to the e-mail address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "密码重置的电子邮件发送到此帐户的电子邮件地址。 如果您未在合理的时间内收到，请优先检查您的垃圾邮件/垃圾邮件文件夹。如果不存在此电子邮件，请咨询系统管理员。",
    "If it is not there ask your local administrator." : "如果它不在此处，请询问您的本地管理员。",
    "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
    "Password can not be changed. Please contact your administrator." : "无法修改密码，请联系管理员。",
    "Back to login" : "返回登录",
    "New password" : "新密码",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "您的文件已经加密。您的密码重置后就没有任何方式能恢复您的数据了。如果您不确定，请在继续前联系您的管理员。您是否真的要继续？",
    "I know what I'm doing" : "我知道我在做什么",
    "Resetting password" : "正在重置密码",
    "Forgot password?" : "忘记密码？",
    "Settings" : "设置",
    "Could not load your contacts" : "无法加载您的联系人",
    "Search contacts …" : "搜索联系人 …",
    "No contacts found" : "无法找到联系人",
    "Show all contacts …" : "显示所有联系人 …",
    "Install the Contacts app" : "安装联系人应用",
    "Loading your contacts …" : "加载您的联系人 …",
    "Looking for {term} …" : "查找 {term} …",
    "No" : "否",
    "Yes" : "是",
    "No files in here" : "未找到文件",
    "New folder" : "新建文件夹",
    "No more subfolders in here" : "没有更多的子文件夹",
    "Name" : "名称",
    "Size" : "大小",
    "Modified" : "已修改",
    "{newName} already exists" : "{newName} 已经存在",
    "Choose" : "选择",
    "Copy" : "复制",
    "Move" : "移动",
    "Error loading file picker template: {error}" : "加载文件选择模板出错：{error}",
    "OK" : "确认",
    "Error loading message template: {error}" : "加载消息模板出错：{error}",
    "read-only" : "只读",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 个文件冲突"],
    "One file conflict" : "1 个文件冲突",
    "New Files" : "新文件",
    "Already existing files" : "已经存在的文件",
    "Which files do you want to keep?" : "请选择需要保留的文件？",
    "If you select both versions, the copied file will have a number added to its name." : "如果同时选择了两个版本，副本的文件名中将会追加数字。",
    "Cancel" : "取消",
    "Continue" : "继续",
    "(all selected)" : "（选中全部）",
    "({count} selected)" : "（选择了 {count} 个）",
    "Error loading file exists template" : "加载文件存在性模板失败",
    "Pending" : "等待",
    "Copy to {folder}" : "复制到 {folder}",
    "Move to {folder}" : "移动到 {folder}",
    "Saving..." : "保存中...",
    "Authentication required" : "授权请求",
    "This action requires you to confirm your password" : "请您确认您的密码",
    "Confirm" : "确认",
    "Failed to authenticate, try again" : "授权失败，请重试",
    "seconds ago" : "几秒前",
    "Connection to server lost" : "与服务器的连接断开",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在 %n 秒后重新加载"],
    "Add to a project" : "添加到项目",
    "Show details" : "显示详情",
    "Hide details" : "隐藏详细信息",
    "Rename project" : "重命名项目",
    "Failed to rename the project" : "无法重命名项目",
    "Failed to create a project" : "无法创建项目",
    "Failed to add the item to the project" : "无法添加条目到项目中",
    "Connect items to a project to make them easier to find" : "将条目关联到项目以使它们更容易查找",
    "Type to search for existing projects" : "输入以搜索已有项目",
    "New in" : "新品",
    "View changelog" : "查看更新记录",
    "No action available" : "无可用操作",
    "Error fetching contact actions" : "查找联系人时出错",
    "Personal" : "个人",
    "Users" : "用户",
    "Apps" : "应用",
    "Admin" : "管理",
    "Help" : "帮助",
    "Access forbidden" : "访问禁止",
    "File not found" : "文件未找到",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "服务器上找不到该文档。可能此共享已被删除或过期。",
    "Back to %s" : "返回 %s",
    "Error" : "错误",
    "Internal Server Error" : "内部服务器错误",
    "The server was unable to complete your request." : "服务器不能完成您的请求。",
    "If this happens again, please send the technical details below to the server administrator." : "如果再次发生，请在下方将技术详情发送给服务器管理员。",
    "More details can be found in the server log." : "更多细节可以在服务器日志中找到。",
    "Technical details" : "技术细节",
    "Remote Address: %s" : "远程地址：%s",
    "Request ID: %s" : "请求 ID：%s",
    "Type: %s" : "类型：%s",
    "Code: %s" : "代码：%s",
    "Message: %s" : "消息：%s",
    "File: %s" : "文件：%s",
    "Line: %s" : "行：%s",
    "Trace" : "追踪",
    "Security warning" : "安全警告",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "因为 .htaccess 文件没有工作，您的数据目录和文件可从互联网被访问。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "了解如何正确配置服务器，请参见 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
    "Create an <strong>admin account</strong>" : "创建 <strong>管理员账号</strong>",
    "Username" : "用户名",
    "Storage & database" : "存储 & 数据库",
    "Data folder" : "数据目录",
    "Configure the database" : "配置数据库",
    "Only %s is available." : "仅 %s 可用。",
    "Install and activate additional PHP modules to choose other database types." : "安装并激活额外的 PHP 模块以选择其他数据库类型。",
    "For more details check out the documentation." : "请查阅文档获得详细信息。",
    "Database user" : "数据库用户",
    "Database password" : "数据库密码",
    "Database name" : "数据库名",
    "Database tablespace" : "数据库表空间",
    "Database host" : "数据库主机",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "请填写主机名称和端口号（例如，localhost:5432）。",
    "Performance warning" : "性能警告",
    "You chose SQLite as database." : "您选择SQLite作为数据库。",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite应只用于最小化和开发实例。生产环境我们推荐使用不同的数据库后端。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "如果您使用文件同步客户端，强烈不建议使用SQLite。",
    "Finish setup" : "安装完成",
    "Finishing …" : "正在完成 …",
    "Need help?" : "需要帮助？",
    "See the documentation" : "查看文档",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "看起来您正在尝试重新安装您的Nextcloud。但您的config文件夹中没有CAN_INSTALL文件。请在您的config文件夹中创建CAN_INSTALL文件以继续。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "无法从config文件夹中移除CAN_INSTALL文件。请手动移除此文件。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "对于正确的操作，该应用需要使用 JavaScript。请 {linkstart}启用 JavaScript{linkend}，并重新加载页面。",
    "Get your own free account" : "获取自己的免费账户",
    "Skip to main content" : "跳过主内容",
    "Skip to navigation of app" : "跳过应用向导",
    "More apps" : "更多的应用程序",
    "More" : "更多",
    "More apps menu" : "更多的应用菜单",
    "Search" : "搜索",
    "Reset search" : "重置搜索",
    "Contacts" : "联系人",
    "Contacts menu" : "联系人菜单",
    "Settings menu" : "设置菜单",
    "Confirm your password" : "确认您的密码",
    "Connect to your account" : "连接您的账户",
    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的 %2$s 账户之前，请先登录。",
    "App token" : "App 令牌",
    "Grant access" : "授权访问",
    "Alternative log in using app token" : "使用应用程序令牌替代登录",
    "Account access" : "账户访问",
    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的 %2$s 账户。",
    "Account connected" : "账号已连接",
    "This share is password-protected" : "这个共享是被密码保护的",
    "The password is wrong. Try again." : "密码错误。请重试。",
    "Two-factor authentication" : "两步验证",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的账户已启用安全增强。请选择第二种验证方式。",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "无法载入您启用的任何两步验证方法。请联系管理员。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "两步验证是强制性的，但您的账户似乎未做配置。请联系管理员获得支持。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "两步验证是强制性的，但您的账户未做配置。请联系管理员配置两步验证。",
    "Set up two-factor authentication" : "配置两步验证",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "两步验证是强制性的，但您的账户似乎未做配置。使用您的备份代码登录或联系管理员。",
    "Use backup code" : "使用备用口令",
    "Cancel log in" : "取消登录",
    "Setup two-factor authentication" : "配置两步验证",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的账户已启用安全增强。请选择提供者进行配置：",
    "Error while validating your second factor" : "验证您的第二项时出错",
    "Access through untrusted domain" : "通过不被信任的域名访问",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "请联系您的管理员。如果您就是管理员，请参照 config.sample.php 中的示例编辑 config/config.php 中的  \"trusted_domains\" 设置。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "配置此项的详细内容请查阅 %1$s文档%2$s。",
    "App update required" : "必须的应用更新",
    "%1$s will be updated to version %2$s" : "%1$s 将被升级至版本 %2$s",
    "These apps will be updated:" : "以下应用将被更新：",
    "These incompatible apps will be disabled:" : "下述不兼容的应用将被禁用：",
    "The theme %s has been disabled." : "%s 主题已被禁用。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在继续之前，请确认数据库、配置文件夹和数据文件夹已经备份。",
    "Start update" : "开始更新",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为避免较大安装时的超时，您可以在安装目录下执行下述的命令：",
    "Detailed logs" : "详细日志",
    "Update needed" : "需要更新",
    "Please use the command line updater because you have a big instance with more than 50 users." : "请使用命令行更新，因为您有一个超过50个用户的大型实例。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">文档</a>。",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道继续通过Web UI进行更新的风险，请求超时运行，并可能导致数据丢失，但我有一个备份，并知道如何恢复。",
    "Upgrade via web on my own risk" : "通过网络升级的风险",
    "Maintenance mode" : "维护模式",
    "This %s instance is currently in maintenance mode, which may take a while." : "该实例 %s 当前处于维护模式，这将花费一些时间。",
    "This page will refresh itself when the instance is available again." : "当实例再次可用时，页面会自动刷新。",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "该用户没有设置电子邮件地址，无发送重置邮件。请联系管理员。",
    "Couldn't send reset email. Please make sure your username is correct." : "无法发送重置邮件，请检查您的用户名是否正确。",
    "Dismiss" : "忽略",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "密码重置邮件已经发送到您的电子邮箱中。如果您长时间没能收到邮件，请检查您邮箱的垃圾/广告文件夹。<br>如果未能收到邮件请联系管理员。",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "您的文件已经加密。当您的密码重置后没有任何方式能恢复您的数据。<br />如果您不确定，请在继续前联系您的管理员。<br/>您是否真的要继续？",
    "Sending email …" : "正在发送邮件…",
    "{name} below version {version} is installed, for stability and performance reasons it is recommended to update to a newer {name} version." : "{name} 已安装 {version} 版本，出于稳定和性能的考虑，建议更新到 {name} 版本。",
    "Accessing site insecurely via HTTP. You are strongly adviced to set up your server to require HTTPS instead, as described in the <a href=\"{docUrl}\">security tips ↗</a>." : "通过 HTTP 访问网站不安全。强烈建议您将服务器设置成 HTTPS 协议，请查阅 <a href=\"{docUrl}\">安全贴士↗</a>。",
    "Shared" : "已共享",
    "Shared with" : "共享给",
    "Shared by" : "共享人",
    "Choose a password for the public link" : "为公开链接设置密码",
    "Choose a password for the public link or press the \"Enter\" key" : "为公开链接设置密码，或按 \"回车\" 键",
    "Copied!" : "已复制！",
    "Copy link" : "复制链接",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "按 ⌘ + C 进行复制。",
    "Press Ctrl-C to copy." : "按  Ctrl + C 进行复制。",
    "Unable to create a link share" : "无法创建共享链接",
    "Unable to toggle this option" : "无法切换此项",
    "Resharing is not allowed" : "不允许二次共享",
    "Link" : "链接",
    "Hide download" : "隐藏下载",
    "Password protection enforced" : "强制密码保护",
    "Password protect" : "密码保护",
    "Allow editing" : "允许编辑",
    "Email link to person" : "发送链接到个人",
    "Send" : "发送",
    "Allow upload and editing" : "允许上传和编辑",
    "Read only" : "只读",
    "File drop (upload only)" : "文件拖拽（仅上传）",
    "Expiration date enforced" : "强制有效期",
    "Set expiration date" : "设置过期日期",
    "Expiration" : "过期",
    "Expiration date" : "过期日期",
    "Note to recipient" : "备注",
    "Unshare" : "取消共享",
    "Delete share link" : "删除共享链接",
    "Add another link" : "添加其他链接",
    "Password protection for links is mandatory" : "强制使用密码保护的链接",
    "Share to {name}" : "共享给 {name}",
    "Share link" : "共享链接",
    "New share link" : "新共享链接",
    "Created on {time}" : "创建于 {time}",
    "Password protect by Talk" : "通过 Talk 保护密码",
    "Could not unshare" : "无法共享",
    "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
    "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
    "Shared with you and the conversation {conversation} by {owner}" : "{owner} 共享给您及对话 {conversation}",
    "Shared with you in a conversation by {owner}" : "由 {owner} 通过一个对话与您分享",
    "Shared with you by {owner}" : "{owner} 共享给您",
    "Choose a password for the mail share" : "为电子邮件共享选择一个密码",
    "group" : "群组",
    "remote" : "外部",
    "remote group" : "远程群组",
    "email" : "邮件",
    "conversation" : "对话",
    "shared by {sharer}" : "由 {sharer} 共享",
    "Can reshare" : "可以再次共享",
    "Can edit" : "可以编辑",
    "Can create" : "可以创建",
    "Can change" : "可以修改",
    "Can delete" : "可以删除",
    "Access control" : "访问控制",
    "{shareInitiatorDisplayName} shared via link" : "{shareInitiatorDisplayName} 通过链接共享",
    "Error while sharing" : "共享时出错",
    "Share details could not be loaded for this item." : "无法加载这个项目的共享详情。",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["{count}字符需要自动完成"],
    "This list is maybe truncated - please refine your search term to see more results." : "此列表可能会被截断 - 请缩短您的搜索词以查看更多结果。",
    "No users or groups found for {search}" : "{search} 条件下没有找到用户或用户组",
    "No users found for {search}" : "没有找到 {search} 用户",
    "An error occurred (\"{message}\"). Please try again" : "发生错误（\"{message}\"）。请重试",
    "An error occurred. Please try again" : "发生错误。请重试",
    "Home" : "家庭",
    "Work" : "工作",
    "Other" : "其他",
    "{sharee} (remote group)" : "{sharee}（远程组）",
    "{sharee} ({type}, {owner})" : "{share}({type},{owner})",
    "Share" : "共享",
    "Name or email address..." : "姓名或电子邮件地址...",
    "Name or federated cloud ID..." : "姓名或联合云 ID...",
    "Name, federated cloud ID or email address..." : "姓名，联合云 ID 或电子邮件地址...",
    "Name..." : "名称...",
    "Error removing share" : "移除共享时出错",
    "SQLite will be used as database." : "SQLite 将被作为数据库使用。",
    "For larger installations we recommend to choose a different database backend." : "在更大的环境下，我们建议选择一个不同的数据库后端。",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "特别当使用桌面客户端来同步文件时，不鼓励使用 SQLite。",
    "Wrong password." : "密码错误。",
    "New Password" : "新密码",
    "We have send a password reset e-mail to the e-mail address known to us for this account. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "我们已将密码重置电子邮件发送到我们已知道的此帐户的电子邮件地址。 如果您未在合理的时间内收到，请检查您的垃圾邮件/垃圾邮件文件夹。<br> 如果不存在，请咨询管理员。",
    "Search globally" : "全局搜索",
    "Your client should now be connected! You can close this window." : "您的客户端现在应该可以连接了！您可以关闭这个窗口。"
},
"nplurals=1; plural=0;");
